@@ -21,19 +21,16 @@ def stacktrace(func=None, exclude_files=["logging", ".pyenv", r".*venv"]):
             if file in caller_filename:
                 return  # ignore in ipython notebooks
         if event == "call":
-            print(caller_filename)
-            print(__name__)
-            if "py_deco" in caller_filename.split("/"):
-                logger.info(f"\033[93mstacktrace starting for {func_name}\033[0m")
-            else:
-                logger.info(
-                    f"\tExecuting {func_name}, line {line_no}, from {caller_filename}"
-                )
+            logger.info(
+                f"\tExecuting {func_name}, line {line_no}, from {caller_filename}"
+            )
             return tracer_func
 
         return
 
     def decorator(func: callable):
+        logger.info(f"\033[93mstacktrace starting for {func.__name__}\033[0m")
+
         def inner(*args, **kwargs):
             settrace(tracer_func)
             func(*args, **kwargs)
